@@ -1,21 +1,20 @@
 /*
- *  Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
- *  Copyright © 2003 Callum McKenzie <callum@physics.otago.ac.nz>
- *  Copyright © 2007, 2008, 2009 Christian Persch
+ * Copyright © 1998, 2003 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright © 2003 Callum McKenzie <callum@physics.otago.ac.nz>
+ * Copyright © 2007, 2008, 2009 Christian Persch
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2, or (at your option)
- *  any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope window it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -83,6 +82,10 @@
 
 #define SELECT_GAME_DIALOG_MIN_HEIGHT (256)
 
+#if !GLIB_CHECK_VERSION (2, 16, 0)
+#define C_(context, string) (_(string))
+#endif
+
 /* define this to enable a debug menu */
 /* #undef ENABLE_DEBUG_UI */
 
@@ -666,7 +669,7 @@ static void
 help_general_cb (GtkAction *action,
                  AisleriotWindow *window)
 {
-  aisleriot_display_help (GTK_WINDOW (window), NULL);
+  aisleriot_show_help (GTK_WIDGET (window), NULL);
 }
 
 static void
@@ -677,7 +680,7 @@ help_on_game_cb (GtkAction *action,
   const char *game_file;
   
   game_file = aisleriot_game_get_game_file (priv->game);
-  aisleriot_display_help (GTK_WINDOW (window), game_file);
+  aisleriot_show_help (GTK_WIDGET (window), game_file);
 }
 
 static void
@@ -1035,6 +1038,9 @@ statusbar_toggled_cb (GtkToggleAction *action,
 
   g_object_set (priv->statusbar, "visible", state, NULL);
 
+  /* Only update the clock continually if it's visible */
+  games_clock_set_update (GAMES_CLOCK (priv->clock), state);
+
   priv->statusbar_visible = state != FALSE;
 
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), state);
@@ -1104,6 +1110,8 @@ clickmove_toggle_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), click_to_move);
 }
 
+#ifdef ENABLE_SOUND
+
 static void
 sound_toggle_cb (GtkToggleAction *action,
                  AisleriotWindow *window)
@@ -1117,6 +1125,8 @@ sound_toggle_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SOUND), sound_enabled);
 }
 
+#endif /* ENABLE_SOUND */
+
 #ifdef HAVE_CLUTTER
 
 static void
@@ -1214,7 +1224,7 @@ apply_option (GtkToggleAction *action,
   action_name = gtk_action_get_name (GTK_ACTION (action));
   value = g_ascii_strtoull (action_name + strlen ("Option"), NULL, 16);
 
-  g_print ("option %s changed, value=%x set=%d\n", action_name, value, active);
+  /* g_print ("option %s changed, value=%x set=%d\n", action_name, value, active); */
 
   *changed_mask |= value;
   if (active)
@@ -1852,7 +1862,7 @@ game_type_changed_cb (AisleriotGame *game,
 #ifdef HAVE_HILDON
   gtk_label_set_text (priv->game_message_label, NULL);
 #else
-  games_clock_set_seconds (GAMES_CLOCK (priv->clock), 0);
+  games_clock_reset (GAMES_CLOCK (priv->clock));
 
   gtk_statusbar_pop (priv->statusbar, priv->game_message_id);
 
@@ -1874,7 +1884,7 @@ game_new_cb (AisleriotGame *game,
 #ifdef HAVE_HILDON
   gtk_label_set_text (priv->game_message_label, NULL);
 #else
-  games_clock_set_seconds (GAMES_CLOCK (priv->clock), 0);
+  games_clock_reset (GAMES_CLOCK (priv->clock));
 
   gtk_statusbar_pop (priv->statusbar, priv->game_message_id);
 #endif
@@ -2285,7 +2295,7 @@ aisleriot_window_init (AisleriotWindow *window)
     { "Toolbar", NULL, N_("_Toolbar"), NULL,
       ACTION_TOOLTIP (N_("Show or hide the toolbar")),
       G_CALLBACK (toolbar_toggled_cb),
-      FALSE
+      TRUE /* active by default since the UI manager creates the toolbar visible */
     },
 #ifndef HAVE_HILDON
     { "Statusbar", NULL, N_("_Statusbar"), NULL,
@@ -2772,6 +2782,7 @@ aisleriot_window_init (AisleriotWindow *window)
   /* Bug alert! maemo#615 and maemo#875
    * Thank you, maemo developers! This bug just cost me 2 hours of my life.
    */
+  /* FIXMEchpe: find out if this is fixed on maemo4 or maemo5 */
   gtk_widget_set_no_show_all (main_vbox, TRUE);
   gtk_widget_show_all (GTK_WIDGET (window));
   if (!priv->toolbar_visible) {
@@ -2971,7 +2982,11 @@ free_load_idle_data (LoadIdleData *data)
   data->window->priv->load_idle_id = 0;
 
   g_free (data->game_file);
+#if GLIB_CHECK_VERSION (2, 10, 0)
   g_slice_free (LoadIdleData, data);
+#else
+  g_free (data);
+#endif
 }
 
 /**
@@ -2997,7 +3012,12 @@ aisleriot_window_set_game (AisleriotWindow *window,
     g_source_remove (priv->load_idle_id);
   }
 
+#if GLIB_CHECK_VERSION (2, 10, 0)
   data = g_slice_new (LoadIdleData);
+#else
+  data = g_new (LoadIdleData, 1);
+#endif
+
   data->window = window;
   data->game_file = g_strdup (game_file);
   data->seed = seed;
